@@ -2,12 +2,11 @@
 #
 # @package      hubzero-submit-distributor
 # @file         Scripts/condor/receiveinput.sh
-# @author       Steve Clark <clarks@purdue.edu>
-# @copyright    Copyright 2004-2011 Purdue University. All rights reserved.
+# @author       Steven Clark <clarks@purdue.edu>
+# @copyright    Copyright 2004-2012 HUBzero Foundation, LLC.
 # @license      http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
 #
-# Copyright (c) 2004-2011 Purdue University
-# All rights reserved.
+# Copyright (c) 2004-2012 HUBzero Foundation, LLC.
 #
 # This file is part of: The HUBzero(R) Platform for Scientific Collaboration
 #
@@ -25,30 +24,18 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #
-# HUBzero is a registered trademark of Purdue University.
+# HUBzero is a registered trademark of HUBzero Foundation, LLC.
 #
 if [ $# -ne 2 ] ; then
    echo usage: $0 jobWorkingDirectory transferredTimestampFile
    exit 64
 fi
 
-rm -rf $1
-mkdir $1
+cd $1
 exitStatus=$?
 
 if [ $exitStatus -eq 0 ] ; then
-   cd $1
-   exitStatus=$?
-
-   if [ $exitStatus -eq 0 ] ; then
-      tar xvzf -
-      exitStatus=$?
-
-      touch .__fileTimeMarker
-      sleep 1
-
-      date +"%s" > $2
-   fi
+   date +"%s" > $2
 fi
 
 exit $exitStatus
